==> docs_sdk_archive_luna-sdk_alma_rel_v.5.31.2.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.31.2/luna-sdk_alma_rel_v.5.31.2/doc/fsdk/html/search/all_0.js <==
var searchData=
[
  ['acquire',['acquire',['../structfsdk_1_1_ref.html#a5d1295bb45a634e8907e6f3ce891e93b',1,'fsdk::Ref::acquire()'],['../namespacefsdk.html#a95e1cb77fe5e1fb43f0f0d671f049234',1,'fsdk::acquire()']]],
  ['acquire_5fas',['acquire_as',['../namespacefsdk.html#a6d4392e13b71ae10f59aa4173a5f449b',1,'fsdk']]],
  ['activatelicense',['activateLicense',['../group___core_group.html#ga1f692a6060c4086c14296eaa7126fdbd',1,'fsdk::activateLicense(ILicense *license, const char *configPath) noexcept'],['../group___core_group.html#ga77194f361bfe0c100680ae1d9000fb29',1,'fsdk::activateLicense(ILicense *license, ISettingsProvider *settings) noexcept']]],
  ['add',['add',['../structfsdk_1_1_i_descriptor_batch.html#acdebdf5cd4b73082fb1f69b7c3673b3e',1,'fsdk::IDescriptorBatch::add(IDescriptor *descriptor) noexcept=0'],['../structfsdk_1_1_i_descriptor_batch.html#a61596b9c2071cf35b9f7b36f78338b31',1,'fsdk::IDescriptorBatch::add(IDescriptorBatch *batch, uint32_t offset=0) noexcept=0'],['../structfsdk_1_1_i_descriptor_batch.html#ab13b6d9a8bc83a2319a2df12ea8fb385',1,'fsdk::IDescriptorBatch::add(IDescriptorBatch *batch, uint32_t offset, uint32_t count) noexcept=0']]],
  ['adjust',['adjust',['../structfsdk_1_1_base_rect.html#ab87b40ffe339e5f9f1140a17f3d102bf',1,'fsdk::BaseRect']]],
  ['adjusted',['adjusted',['../structfsdk_1_1_base_rect.html#ab984f957869ca6d59810885178e42a25',1,'fsdk::BaseRect']]],
  ['age',['age',['../structfsdk_1_1_human_attribute_result.html#ad0fe8de701b954abbc3bd3ac7be80cf5',1,'fsdk::HumanAttributeResult']]],
  ['aggregate',['aggregate',['../structfsdk_1_1_i_human_attribute_estimator.html#a1cab67b058b9b74038746fcc5481fcf7',1,'fsdk::IHumanAttributeEstimator']]],
  ['ags',['ags',['../structfsdk_1_1_i_best_shot_quality_estimator_1_1_estimation_result.html#ad62dfcec240364328eff4eb65b75ba72',1,'fsdk::IBestShotQualityEstimator::EstimationResult']]],
  ['alive',['Alive',['../structfsdk_1_1_liveness_one_shot_r_g_b_estimation.html#a0a15d2c39c2975369d9ad85b53392f56abd9f7c5d6ab4201b138a3e51dab7056f',1,'fsdk::LivenessOneShotRGBEstimation']]],
  ['allocate',['allocate',['../structfsdk_1_1_image.html#aef4ba8f782d69628ffaffc4da6ed970f',1,'fsdk::Image']]],
  ['anger',['anger',['../structfsdk_1_1_emotions_estimation.html#abf6537ce2f1adfc79f8079f6cfe68d42',1,'fsdk::EmotionsEstimation']]],
  ['apparentcolor',['ApparentColor',['../structfsdk_1_1_human_attribute_result.html#ac2d2f979e2a807f45b8f01467f78732b',1,'fsdk::HumanAttributeResult']]],
  ['apparentcolorestimation',['ApparentColorEstimation',['../structfsdk_1_1_human_attribute_result_1_1_apparent_color_estimation.html',1,'fsdk::HumanAttributeResult']]],
  ['append',['append',['../structfsdk_1_1_sizer.html#adc34d459d74906d4e2a8e8efeffe1339',1,'fsdk::Sizer::append(size_t bytes) noexcept'],['../structfsdk_1_1_sizer.html#ab278930212c03f5f2dba82281b2b8a63',1,'fsdk::Sizer::append(const Sizer &amp;other) noexcept']]],
  ['appendbatch',['appendBatch',['../structfsdk_1_1_i_dynamic_descriptor_storage.html#acee6a3d1822e97dad564278715b3a596',1,'fsdk::IDynamicDescriptorStorage']]],
  ['appenddescriptor',['appendDescriptor',['../structfsdk_1_1_i_dynamic_descriptor_storage.html#a78a1d8242a8574bcde70c070602bc1fa',1,'fsdk::IDynamicDescriptorStorage']]],
  ['appendinvalidroot',['AppendInvalidRoot',['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5a29ebf8fe305fd42de0b208c9dc226559',1,'fsdk::ISettingsProvider']]],
  ['archiveread',['ArchiveRead',['../structfsdk_1_1_i_serializable_object.html#a2e8ee7bbbbc97731f3dddfcf9c5276f0a475e42b82c23aaaa94f66c43f80a14d1',1,'fsdk::ISerializableObject']]],
  ['archivewrite',['ArchiveWrite',['../structfsdk_1_1_i_serializable_object.html#a2e8ee7bbbbc97731f3dddfcf9c5276f0a5b9364e023e7cee301db9754a421d258',1,'fsdk::ISerializableObject']]],
  ['as',['as',['../structfsdk_1_1_ref.html#a74485eedefcd2c2f032a61bce36a2492',1,'fsdk::Ref']]],
  ['asbool',['asBool',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a81865a1f56ef1450a47de5d8e8866c6d',1,'fsdk::ISettingsProvider::Value']]],
  ['asfloat',['asFloat',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a6070b50e16d3cbcd5a49c018b6d631c8',1,'fsdk::ISettingsProvider::Value']]],
  ['asint',['asInt',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a9dc95a2a7f10e8860915a14565a86f73',1,'fsdk::ISettingsProvider::Value']]],
  ['aspoint2f',['asPoint2f',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a89993c2d966d24f4d8f1800d25af4071',1,'fsdk::ISettingsProvider::Value']]],
  ['aspoint2i',['asPoint2i',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a62b3eff07e0687047a65e18939f4a1af',1,'fsdk::ISettingsProvider::Value']]],
  ['asrect',['asRect',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a320c5395ac81284ee738283ef07f6f32',1,'fsdk::ISettingsProvider::Value']]],
  ['assign',['assign',['../structfsdk_1_1_ref.html#aed37366a7149bed9a7d7c322bd7bef91',1,'fsdk::Ref']]],
  ['assize',['asSize',['../structfsdk_1_1_i_settings_provider_1_1_value.html#ac401f96faea0d11e79f92e66416e560d',1,'fsdk::ISettingsProvider::Value']]],
  ['asstring',['asString',['../structfsdk_1_1_i_settings_provider_1_1_value.html#acf75100534bf1b7c7d9536ace5b8dca8',1,'fsdk::ISettingsProvider::Value']]],
  ['async',['Async',['../namespacefsdk.html#a0f4cbbc8c61f0127bd75695e76869860a24aa4117da86c41684ad25742832dfa6',1,'fsdk']]]
];

==> docs_sdk_archive_luna-sdk_alma_rel_v.5.34.0.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.34.0/luna-sdk_alma_rel_v.5.34.0/doc/fsdk/html/search/all_0.js <==
var searchData=
[
  ['acquire',['acquire',['../structfsdk_1_1_ref.html#a5d1295bb45a634e8907e6f3ce891e93b',1,'fsdk::Ref::acquire()'],['../namespacefsdk.html#a95e1cb77fe5e1fb43f0f0d671f049234',1,'fsdk::acquire()']]],
  ['acquire_5fas',['acquire_as',['../namespacefsdk.html#a6d4392e13b71ae10f59aa4173a5f449b',1,'fsdk']]],
  ['activatelicense',['activateLicense',['../group___core_group.html#ga1f692a6060c4086c14296eaa7126fdbd',1,'fsdk::activateLicense(ILicense *license, const char *configPath) noexcept'],['../group___core_group.html#ga77194f361bfe0c100680ae1d9000fb29',1,'fsdk::activateLicense(ILicense *license, ISettingsProvider *settings) noexcept']]],
  ['add',['add',['../structfsdk_1_1_i_descriptor_batch.html#acdebdf5cd4b73082fb1f69b7c3673b3e',1,'fsdk::IDescriptorBatch::add(IDescriptor *descriptor) noexcept=0'],['../structfsdk_1_1_i_descriptor_batch.html#a61596b9c2071cf35b9f7b36f78338b31',1,'fsdk::IDescriptorBatch::add(IDescriptorBatch *batch, uint32_t offset=0) noexcept=0'],['../structfsdk_1_1_i_descriptor_batch.html#ab13b6d9a8bc83a2319a2df12ea8fb385',1,'fsdk::IDescriptorBatch::add(IDescriptorBatch *batch, uint32_t offset, uint32_t count) noexcept=0']]],
  ['adjust',['adjust',['../structfsdk_1_1_base_rect.html#ab87b40ffe339e5f9f1140a17f3d102bf',1,'fsdk::BaseRect']]],
  ['adjusted',['adjusted',['../structfsdk_1_1_base_rect.html#ab984f957869ca6d59810885178e42a25',1,'fsdk::BaseRect']]],
  ['age',['age',['../structfsdk_1_1_human_attribute_result.html#ad0fe8de701b954abbc3bd3ac7be80cf5',1,'fsdk::HumanAttributeResult']]],
  ['aggregate',['aggregate',['../structfsdk_1_1_i_human_attribute_estimator.html#a1cab67b058b9b74038746fcc5481fcf7',1,'fsdk::IHumanAttributeEstimator']]],
  ['ags',['ags',['../structfsdk_1_1_i_best_shot_quality_estimator_1_1_estimation_result.html#ad62dfcec240364328eff4eb65b75ba72',1,'fsdk::IBestShotQualityEstimator::EstimationResult']]],
  ['aid',['AID',['../structfsdk_1_1_a_i_d.html',1,'fsdk']]],
  ['alive',['Alive',['../structfsdk_1_1_liveness_one_shot_r_g_b_estimation.html#a0a15d2c39c2975369d9ad85b53392f56abd9f7c5d6ab4201b138a3e51dab7056f',1,'fsdk::LivenessOneShotRGBEstimation']]],
  ['allocate',['allocate',['../structfsdk_1_1_image.html#aef4ba8f782d69628ffaffc4da6ed970f',1,'fsdk::Image']]],
  ['anger',['anger',['../structfsdk_1_1_emotions_estimation.html#abf6537ce2f1adfc79f8079f6cfe68d42',1,'fsdk::EmotionsEstimation']]],
  ['apparentcolor',['ApparentColor',['../structfsdk_1_1_human_attribute_result.html#ac2d2f979e2a807f45b8f01467f78732b',1,'fsdk::HumanAttributeResult']]],
  ['apparentcolorestimation',['ApparentColorEstimation',['../structfsdk_1_1_human_attribute_result_1_1_apparent_color_estimation.html',1,'fsdk::HumanAttributeResult']]],
  ['append',['append',['../structfsdk_1_1_sizer.html#adc34d459d74906d4e2a8e8efeffe1339',1,'fsdk::Sizer::append(size_t bytes) noexcept'],['../structfsdk_1_1_sizer.html#ab278930212c03f5f2dba82281b2b8a63',1,'fsdk::Sizer::append(const Sizer &amp;other) noexcept']]],
  ['appendbatch',['appendBatch',['../structfsdk_1_1_i_dynamic_descriptor_storage.html#acee6a3d1822e97dad564278715b3a596',1,'fsdk::IDynamicDescriptorStorage']]],
  ['appenddescriptor',['appendDescriptor',['../structfsdk_1_1_i_dynamic_descriptor_storage.html#a78a1d8242a8574bcde70c070602bc1fa',1,'fsdk::IDynamicDescriptorStorage']]],
  ['appendinvalidroot',['AppendInvalidRoot',['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5a29ebf8fe305fd42de0b208c9dc226559',1,'fsdk::ISettingsProvider']]],
  ['archiveread',['ArchiveRead',['../structfsdk_1_1_i_serializable_object.html#a2e8ee7bbbbc97731f3dddfcf9c5276f0a475e42b82c23aaaa94f66c43f80a14d1',1,'fsdk::ISerializableObject']]],
  ['archivewrite',['ArchiveWrite',['../structfsdk_1_1_i_serializable_object.html#a2e8ee7bbbbc97731f3dddfcf9c5276f0a5b9364e023e7cee301db9754a421d258',1,'fsdk::ISerializableObject']]],
  ['as',['as',['../structfsdk_1_1_ref.html#a74485eedefcd2c2f032a61bce36a2492',1,'fsdk::Ref']]],
  ['asbool',['asBool',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a81865a1f56ef1450a47de5d8e8866c6d',1,'fsdk::ISettingsProvider::Value']]],
  ['asfloat',['asFloat',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a6070b50e16d3cbcd5a49c018b6d631c8',1,'fsdk::ISettingsProvider::Value']]],
  ['asint',['asInt',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a9dc95a2a7f10e8860915a14565a86f73',1,'fsdk::ISettingsProvider::Value']]],
  ['aspoint2f',['asPoint2f',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a89993c2d966d24f4d8f1800d25af4071',1,'fsdk::ISettingsProvider::Value']]],
  ['aspoint2i',['asPoint2i',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a62b3eff07e0687047a65e18939f4a1af',1,'fsdk::ISettingsProvider::Value']]],
  ['asrect',['asRect',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a320c5395ac81284ee738283ef07f6f32',1,'fsdk::ISettingsProvider::Value']]],
  ['assign',['assign',['../structfsdk_1_1_ref.html#aed37366a7149bed9a7d7c322bd7bef91',1,'fsdk::Ref']]],
  ['assize',['asSize',['../structfsdk_1_1_i_settings_provider_1_1_value.html#ac401f96faea0d11e79f92e66416e560d',1,'fsdk::ISettingsProvider::Value']]],
  ['asstring',['asString',['../structfsdk_1_1_i_settings_provider_1_1_value.html#acf75100534bf1b7c7d9536ace5b8dca8',1,'fsdk::ISettingsProvider::Value']]],
  ['asulong',['asULong',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a7397a979fe9dc526d22818865e4331b1',1,'fsdk::ISettingsProvider::Value']]],
  ['async',['Async',['../namespacefsdk.html#a0f4cbbc8c61f0127bd75695e76869860a24aa4117da86c41684ad25742832dfa6',1,'fsdk']]]
];
